#########
  Theory
#########

.. toctree::
   :maxdepth: 1
    
   Kernels on compact manifolds <compact>
   Addition theorem <addition_theorem>
   Kernels on graphs <graphs>
   Kernels on meshes <meshes>
   Kernels on non-compact symmetric spaces <symmetric>
   Kernels on product spaces <product_spaces>
   Product kernels <product_kernels>
   Feature maps and sampling <feature_maps>
   Hypercube graph space <hypercube_graph>
